@@ -101,6 +101,9 @@
 #ifdef HAVE_SYS_SYSMP_H
 # include <sys/sysmp.h>
 #endif
+#ifdef HAVE_SYS_SYSGET_H
+# include <sys/sysget.h>
+#endif
 #ifdef HAVE_UTIME_H
 # include <utime.h>
 #endif
@@ -321,9 +324,9 @@ void disablesignals(void);
 void getnames(void);
 void donlist(char *arg, int on_ctrlconn);
 int opendata(void);
-void addreply(int, const char *, ...) 
+void addreply(const int code, const char * const line, ...)
 	__attribute__ ((format(printf, 2, 3)));
-void addreply_noformat(int, const char *);
+void addreply_noformat(const int code, const char * const line);
 void doreply(void);
 void sighandler(int sig);
 void prevent(char *arg);
@@ -363,15 +366,27 @@ extern int opt_a, opt_C, opt_d, opt_F, opt_l, opt_R;
 #define FAKE_SHELL "ftp"
 
 #ifndef PID_FILE
-# define PID_FILE "/var/run/pure-ftpd.pid"
+# ifdef NON_ROOT_FTP
+#  define PID_FILE CONFDIR "/pure-ftpd.pid"
+# else
+#  define PID_FILE "/var/run/pure-ftpd.pid"
+# endif
 #endif
 
 #ifndef UPLOADSCRIPT_PID_FILE
-# define UPLOADSCRIPT_PID_FILE "/var/run/pure-uploadscript.pid"
+# ifdef NON_ROOT_FTP
+#  define UPLOADSCRIPT_PID_FILE CONFDIR "/pure-uploadscript.pid"
+# else
+#  define UPLOADSCRIPT_PID_FILE "/var/run/pure-uploadscript.pid"
+# endif
 #endif
 
 #ifndef AUTHD_PID_FILE
-# define AUTHD_PID_FILE "/var/run/pure-authd.pid"
+# ifdef NON_ROOT_FTP
+#  define AUTHD_PID_FILE CONFDIR "/pure-authd.pid"
+# else
+#  define AUTHD_PID_FILE "/var/run/pure-authd.pid"
+# endif
 #endif
 
 #ifndef NON_ROOT_FTP
