@@ -3,7 +3,11 @@
 
 #ifdef FTPWHO
 
-#define SCOREBOARD_PATH "/var/run/pure-ftpd"
+# ifdef NON_ROOT_FTP
+#  define SCOREBOARD_PATH CONFDIR "/pure-ftpd-ftpwho"
+# else
+#  define SCOREBOARD_PATH "/var/run/pure-ftpd"
+# endif
 #define SCOREBOARD_PREFIX "client-"
 
 typedef enum {
