@@ -71,7 +71,6 @@ GLOBAL(unsigned int max_ls_files, DEFAULT_MAX_LS_FILES);
 GLOBAL(unsigned int max_ls_depth, DEFAULT_MAX_LS_DEPTH);
 GLOBAL0(char *fortunes_file);
 GLOBAL0(char host[NI_MAXHOST]);
-GLOBAL0(struct reply *lastreply);
 GLOBAL0(int replycode);
 GLOBAL0(signed char force_ls_a);
 GLOBAL0(struct sockaddr_storage peer);
@@ -80,7 +79,7 @@ GLOBAL0(unsigned short int peerdataport);
 GLOBAL0(double maxload);
 GLOBAL(unsigned int maxusers, DEFAULT_MAX_USERS);
 GLOBAL0(int iptropy);
-GLOBAL(int xferfd, -1);
+GLOBAL(volatile int xferfd, -1);
 #ifndef NO_STANDALONE
 GLOBAL0(unsigned int maxip);
 #endif
@@ -114,7 +113,7 @@ GLOBAL0(FTPWhoEntry *shm_data);
 GLOBAL0(FTPWhoEntry *shm_data_cur);
 #endif
 
-#if defined(WITH_UPLOAD_SCRIPT) && !defined(NON_ROOT_FTP)
+#if defined(WITH_UPLOAD_SCRIPT)
 GLOBAL0(signed char do_upload_script);
 GLOBAL(int upload_pipe_fd, -1);
 GLOBAL(int upload_pipe_lock, -1);
@@ -150,4 +149,6 @@ GLOBAL0(time_t session_start_time);
 GLOBAL(const char *pid_file, PID_FILE);
 #endif
 
+GLOBAL0(signed char be_customer_proof);
+
 #endif
