@@ -64,38 +64,68 @@ static void callback_reply_slow_tilde_expansion(const char *str, AuthResult * co
 
 static void callback_reply_throttling_bandwidth_ul(const char *str, AuthResult * const result)
 {
+#ifdef WITH_THROTTLING
     result->throttling_bandwidth_ul = strtoul(str, NULL, 10);
     result->throttling_ul_changed = 1;
+#else
+    (void) str;
+    (void) result;
+#endif
 }
 
 static void callback_reply_throttling_bandwidth_dl(const char *str, AuthResult * const result)
 {
+#ifdef THROTTLING
     result->throttling_bandwidth_dl = strtoul(str, NULL, 10);
-    result->throttling_dl_changed = 1;    
+    result->throttling_dl_changed = 1;
+#else
+    (void) str;
+    (void) result;
+#endif
 }
 
 static void callback_reply_user_quota_size(const char *str, AuthResult * const result)
 {
+#ifdef QUOTAS
     result->user_quota_size = strtoull(str, NULL, 10);
     result->quota_size_changed = 1;
+#else
+    (void) str;
+    (void) result;
+#endif
 }
 
 static void callback_reply_user_quota_files(const char *str, AuthResult * const result)
 {
+#ifdef QUOTAS
     result->user_quota_files = strtoull(str, NULL, 10);
     result->quota_files_changed = 1;
+#else
+    (void) str;
+    (void) result;
+#endif
 }
 
 static void callback_reply_ratio_upload(const char *str, AuthResult * const result)
 {
+#ifdef RATIOS
     result->ratio_upload = (unsigned int) strtoul(str, NULL, 10);
     result->ratio_ul_changed = 1;
+#else
+    (void) str;
+    (void) result;
+#endif
 }   
 
 static void callback_reply_ratio_download(const char *str, AuthResult * const result)
 {
+#ifdef RATIO
     result->ratio_download = (unsigned int) strtoul(str, NULL, 10);
-    result->ratio_dl_changed = 1;    
+    result->ratio_dl_changed = 1;
+#else
+    (void) str;
+    (void) result;
+#endif
 }
 
 static void callback_reply_end(const char *str, AuthResult * const result)
@@ -169,30 +199,20 @@ void pw_extauth_check(AuthResult * const result,
         }
         goto bye;
     }
-    snprintf(line, sizeof line, EXTAUTH_CLIENT_ACCOUNT "%s\n", account);
-    if (safe_write(kindy, line, strlen(line)) != 0) {
+    if (SNCHECK(snprintf(line, sizeof line, 
+                         EXTAUTH_CLIENT_ACCOUNT "%s\n"
+                         EXTAUTH_CLIENT_PASSWORD "%s\n"
+                         EXTAUTH_CLIENT_SA_HOST "%s\n"
+                         EXTAUTH_CLIENT_SA_PORT "%s\n"
+                         EXTAUTH_CLIENT_PEER_HOST "%s\n"
+                         EXTAUTH_CLIENT_END "\n",
+                         account, password, sa_hbuf, sa_port, peer_hbuf), 
+                sizeof line)) {
         goto bye;
     }
-    snprintf(line, sizeof line, EXTAUTH_CLIENT_PASSWORD "%s\n", password);
-    if (safe_write(kindy, line, strlen(line)) != 0) {
-        goto bye;
-    }
-    snprintf(line, sizeof line, EXTAUTH_CLIENT_SA_HOST "%s\n", sa_hbuf);
     if (safe_write(kindy, line, strlen(line)) != 0) {
         goto bye;
     }    
-    snprintf(line, sizeof line, EXTAUTH_CLIENT_SA_PORT "%s\n", sa_port);
-    if (safe_write(kindy, line, strlen(line)) != 0) {
-        goto bye;
-    }    
-    snprintf(line, sizeof line, EXTAUTH_CLIENT_PEER_HOST "%s\n", peer_hbuf);
-    if (safe_write(kindy, line, strlen(line)) != 0) {
-        goto bye;
-    }
-    if (safe_write(kindy, EXTAUTH_CLIENT_END "\n", 
-                   (sizeof EXTAUTH_CLIENT_END - 1U) + 1U) != 0) {
-        goto bye;
-    }
     result->uid = (uid_t) 0;
     result->gid = (gid_t) 0;
     result->dir = NULL;
