@@ -8,6 +8,25 @@
 #define LDAP_HOMEDIRECTORY "homeDirectory"
 #define LDAP_USERPASSWORD "userPassword"
 #define LDAP_LOGINSHELL "loginShell"
+#define LDAP_FTPUID "FTPuid"
+#define LDAP_FTPGID "FTPgid"
+
+#define LDAP_FTPSTATUS "FTPStatus"
+
+#ifdef QUOTAS
+# define LDAP_QUOTAFILES "FTPQuotaFiles"
+# define LDAP_QUOTAMBYTES "FTPQuotaMBytes"
+#endif
+
+#ifdef RATIOS
+# define LDAP_DOWNLOADRATIO "FTPDownloadRatio"
+# define LDAP_UPLOADRATIO "FTPUploadRatio"
+#endif
+
+#ifdef THROTTLING
+# define LDAP_DOWNLOADBANDWIDTH "FTPDownloadBandwidth"
+# define LDAP_UPLOADBANDWIDTH "FTPUploadBandwidth"
+#endif
 
 #define MAX_LDAP_UID_LENGTH 256U
 #define DEFAULT_SHELL "ftp"
