@@ -537,7 +537,7 @@ static FileInfo *sreaddir(char **names_pnt)
         free(names);
         return NULL;
     }
-    while ((de = readdir(d)) != NULL) {
+    while ((de = readdir(d)) != NULL) {        
         if (lstat(de->d_name, &st) < 0) {
             continue;
         }
@@ -759,7 +759,7 @@ void donlist(char *arg, int on_ctrl_conn)
         }
         doreply();
         if (type == 2) {
-            addreply(0, "ASCII");
+            addreply_noformat(0, "ASCII");
         }
     } else {                           /* STAT command */
         c = 1;
@@ -780,7 +780,7 @@ void donlist(char *arg, int on_ctrl_conn)
                 justone = 0;
             }
 #ifdef DEBUG
-            if (debug) {
+            if (debug != 0) {
                 addreply(226, "Glob: %s", arg);
             }
 #endif
@@ -840,12 +840,12 @@ void donlist(char *arg, int on_ctrl_conn)
             } else {
                 if (a == GLOB_NOSPACE) {
                     addreply(226, MSG_GLOB_NO_MEMORY, arg);
-                    addreply(0, MSG_PROBABLY_DENIED);
+                    addreply_noformat(0, MSG_PROBABLY_DENIED);
                 } else if (a == GLOB_ABEND) {
                     addreply(226, MSG_GLOB_READ_ERROR, arg);
                 } else if (a != GLOB_NOMATCH) {
                     addreply(226, MSG_GLOB_READ_ERROR, arg);
-                    addreply(0, MSG_PROBABLY_DENIED);                    
+                    addreply_noformat(0, MSG_PROBABLY_DENIED);                    
                 }
             }
             globfree(&g);
@@ -863,7 +863,7 @@ void donlist(char *arg, int on_ctrl_conn)
     if (on_ctrl_conn == 0) {
         close(c);
     } else {
-        addreply(213, "End.");
+        addreply_noformat(213, "End.");
         goto end;
     }
     if (opt_a || opt_C || opt_d || opt_F || opt_l || opt_r || opt_R ||
