@@ -105,7 +105,7 @@
     "pas encore ete modere par les administrateurs pour le download."
 #define MSG_RATIO_DENIAL \
     "Le ratio upload/download est de %u:%u .\n" \
-    "Vous avez uploade %llu KO et downloade %llu KO.\n" \
+    "Vous avez uploade %llu Ko et downloade %llu Ko.\n" \
     "Veuillez uploader quelque chose avant de downloader autre chose."
 #define MSG_NO_MORE_TO_DOWNLOAD "Plus rien a downloader"
 #define MSG_WINNER "Cet ordinateur est votre ami. Faites lui confiance"
