@@ -209,7 +209,7 @@
 #define MSG_QUOTA_EXCEEDED "Ÿ ʰǾ : %s   ʾ"
 #define MSG_AUTH_UNKNOWN "߸  "
 #define MSG_PDB_BROKEN "puredb ε    (Ǵ   ν ) - pure-pw mkdb  õ "
-#define MSG_ALIASES_ALIAS "%s is an alias for %s."
-#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
-#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
-#define MSG_ALIASES_LIST "The following aliases are available :"
+#define MSG_ALIASES_ALIAS "%s %s Ī."
+#define MSG_ALIASES_UNKNOWN "   Ī %s."
+#define MSG_ALIASES_BROKEN_FILE "ջ Ī "
+#define MSG_ALIASES_LIST " Ī  :"
