@@ -209,3 +209,7 @@
 #define MSG_QUOTA_EXCEEDED "Quota overschreden: %s worden niet opgeslagen"
 #define MSG_AUTH_UNKNOWN "Onbekende autorisatie methode"
 #define MSG_PDB_BROKEN "Unable to read the indexed puredb file (or old format detected) - Try pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s is an alias for %s."
+#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
+#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
+#define MSG_ALIASES_LIST "The following aliases are available :"
