@@ -1,4 +1,4 @@
-#define MSG_TIMEOUT "Timeout"
+#define MSG_TIMEOUT "Cas vyprsal"
 #define MSG_CAPABILITIES "Nemozem zmenit privilegia"
 #define MSG_CLIENT_CLOSED_CNX "Klient zavrel spojenie"
 #define MSG_CLIENT_READ_ERR "Chyba pri citani od klienta"
@@ -30,8 +30,8 @@
 #define MSG_UNKNOWN_EXTENSION "je nezname rozsirenie"
 #define MSG_XDBG_OK "Prikaz XDBG bol uspesny, debug uroven je teraz %d"
 #define MSG_UNKNOWN_COMMAND "Neznamy prikaz"
-#define MSG_TIMEOUT_NOOP "Timeout (ziadna operacia za %lu sekund)"
-#define MSG_TIMEOUT_DATA "Timeout (ziadne nove data za %lu sekund)"
+#define MSG_TIMEOUT_NOOP "Cas vyprsal (ziadna operacia za %lu sekund)"
+#define MSG_TIMEOUT_DATA "Cas vyprsal (ziadne nove data za %lu sekund)"
 #define MSG_SLEEPING "Zzz..."
 #define MSG_ALREADY_LOGGED "Uz ste prihlaseny"
 #define MSG_ANY_PASSWORD "Lubovolne heslo bude fungovat"
@@ -208,8 +208,8 @@
 #define MSG_QUOTA_SIZE "%llu kilobajtov pouzitych (%d%%) - autorizovanych: %llu kilobajtov"
 #define MSG_QUOTA_EXCEEDED "Kvota prekrocena : %s nebude ulozeny"
 #define MSG_AUTH_UNKNOWN "Neznama autentifikacna metoda"
-#define MSG_PDB_BROKEN "Unable to read the indexed puredb file (or old format detected) - Try pure-pw mkdb"
-#define MSG_ALIASES_ALIAS "%s is an alias for %s."
-#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
-#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
-#define MSG_ALIASES_LIST "The following aliases are available :"
+#define MSG_PDB_BROKEN "Nebolo mozne precitat indexovany subor puredb (alebo bola detekovana stara verzia) - Vyskusajte spustit pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s je aliasom pre %s."
+#define MSG_ALIASES_UNKNOWN "Neznamy alias %s."
+#define MSG_ALIASES_BROKEN_FILE "Poskodeny subor aliasov"
+#define MSG_ALIASES_LIST "Nasledovne aliasy su dostupne :"
