@@ -22,6 +22,10 @@
 # include <dmalloc.h>
 #endif
 
+#ifdef PROBE_RANDOM_AT_RUNTIME
+static const char *random_device;
+#endif
+
 static void disable_echo(void)
 {
     if (!isatty(0)) {
@@ -203,13 +207,33 @@ static void no_mem(void)
     exit(EXIT_FAILURE);
 }
 
+#ifdef PROBE_RANDOM_AT_RUNTIME
+static void pw_zrand_probe(void)
+{
+    static const char * const devices[] = {
+        "/dev/arandom", "/dev/urandom", "/dev/random", NULL
+    };
+    register const char * const *device = devices;
+    
+    do {
+        if (access(*device, F_OK | R_OK) == 0) {
+            random_device = *device;
+            break;
+        }
+        device++;
+    } while (*device != NULL);
+}
+#endif
+
 static unsigned int pw_zrand(void)
 {
     int fd;
     int ret;
     
     if (
-#ifdef HAVE_DEV_ARANDOM
+#ifdef PROBE_RANDOM_AT_RUNTIME
+        ((fd = open(random_device, O_RDONLY | O_NONBLOCK)) == -1)
+#elif defined(HAVE_DEV_ARANDOM)
         ((fd = open("/dev/arandom", O_RDONLY | O_NONBLOCK)) == -1)
 #elif defined(HAVE_DEV_URANDOM)
         ((fd = open("/dev/urandom", O_RDONLY | O_NONBLOCK)) == -1)
@@ -495,7 +519,7 @@ static FILE *create_newpasswd(const char * const file,
     char line[LINE_MAX];
     
     fp = fopen(file, "rt");    
-    if ((fd2 = open(file2, O_EXCL | O_NOFOLLOW | 
+    if ((fd2 = open(file2, O_EXCL | O_NOFOLLOW |
                     O_CREAT | O_WRONLY, (mode_t) 0700)) == -1) {
         if (fp != NULL) {
             fclose(fp);
@@ -1186,6 +1210,10 @@ int main(int argc, char *argv[])
     (void) setlocale(LC_COLLATE, "");
 # endif
 #endif    
+
+#ifdef PROBE_RANDOM_AT_RUNTIME
+    pw_zrand_probe();
+#endif
     
     pwinfo.pwd = NULL;
     pwinfo.gecos = NULL;
