@@ -17,7 +17,6 @@
 static uid_t uid;
 static gid_t gid;
 static const char *startpath;
-static const char *user;
 static unsigned long long total_size;
 static unsigned long long total_files;
 static signed char isroot;
@@ -150,11 +149,11 @@ static void help(void)
     exit(EXIT_SUCCESS);
 }
 
-static int doinitsupgroups(const char *user, const uid_t uid, const uid_t gid)
+static int doinitsupgroups(const char *user, const uid_t uid, const gid_t gid)
 {
 #ifndef NON_ROOT_FTP
 # ifdef HAVE_SETGROUPS
-    if (setgroups(sizeof(gid) / sizeof(gid_t), &gid) != 0) {
+    if (setgroups(1U, &gid) != 0) {
         return -1;
     }
 # else
@@ -330,9 +329,6 @@ int main(int argc, char *argv[])
                     return -1;
                 }
                 if ((pw = getpwnam(optarg)) != NULL) {
-                    if ((user = strdup(pw->pw_name)) == NULL) {
-			oom();
-                    }
                     uid = pw->pw_uid;
                     if (gid == (gid_t) 0) {
                         gid = pw->pw_gid;
